package main

import (
	"net/http"

	"github.com/beego/beego/v2/core/logs"
	"github.com/beego/beego/v2/server/web"
)

// 定义 Controller
type CookieController struct {
	web.Controller
}

// Get curl -H "Cookie:name=value; name2=value2; name3=value3"
func (c *CookieController) Get() {
	// 获取 cookies
	// 方法一
	//c.Ctx.Request.Cookie(name)
	for _, cookie := range c.Ctx.Request.Cookies() {
		logs.Info("cookie: %s", cookie)
	}

	// 方法二
	c.Ctx.WriteString(c.Ctx.Input.Cookie("name"))
	c.Ctx.WriteString("\n")

	// 方式三
	c.Ctx.WriteString(c.Ctx.GetCookie("name"))

	cookie := http.Cookie{
		Name:  "namebeego1",
		Value: "value1",
	}
	http.SetCookie(c.Ctx.ResponseWriter, &cookie)
	c.Ctx.SetCookie("namebeego2", "valuebeego") // Get 方法没有生效？
	c.Ctx.WriteString("")
}

func (c *CookieController) Post() {
	// 设置 cookie
	// 方式一：
	cookie := http.Cookie{
		Name:  "namebeego1",
		Value: "v1",
	}
	http.SetCookie(c.Ctx.ResponseWriter, &cookie)
	c.Ctx.SetCookie("namebeego2", "v2")

	// SecureCookie 加密 cookie
	//c.SetSecureCookie()
	secret := "abcd"
	v3, result := c.GetSecureCookie(secret, "namebeego3")
	logs.Info("sc", v3, result)
	c.Ctx.SetSecureCookie(secret, "namebeego3", "v3")
	c.Ctx.WriteString("")
}

func main() {
	web.Router("/cookie/", &CookieController{})

	web.Run()
}
